utils.Report (Report) — amici1

# `utils.Report` (Report)

`lino.utils.report.Report`

A special kind of `EmptyTable` used to create „reports“. A report is a series of headings, paragraphs and tables combined into a single printable and previewable document.

When subclassing this, application code must either define `report_items` or implement an alternative `get_story()`.

Usage examples: `lino_xl.lib.courses.StatusReport` `lino_welfare.modlib.integ.ActivityReport`

Note that there is also `lino.modlib.users.UserPlan` and `lino.mixins.Story` for more expensive „reports“ where you use cached data `lino_xl.lib.sheets.Report`.

## Filter parameters